@@ -143,10 +143,7 @@ class Smart(Generic[T]):
         self._trace: str = ''
 
         self._callable = _callable
-        self._params: Dict[str, Any] = dict()
-
-        for key, value in kwargs.items():
-            self.set(key, value)
+        self._params: Dict[str, Any] = dictutil.normalize(kwargs)
 
         if callable(smart_init := getattr(self._callable, '__smart_init__', None)):
             smart_init(self)
@@ -190,7 +187,10 @@ class Smart(Generic[T]):
             callable_=self._callable,
             trace=self._trace,
             args=args,
-            kwargs=params,
+            kwargs=self._init_dict(
+                dictionary=params,
+                trace=self._trace,
+            ),
         )
 
     def __str__(self) -> str:
@@ -333,8 +333,13 @@ class Smart(Generic[T]):
         dictionary, last_key = dictutil.find_nested(
             dictionary=self._params,
             key=key,
+            create_mode=True,
             set_mode=True,
         )
+
+        if isinstance(value, dict):
+            value = dictutil.normalize(value)
+
         dictionary[last_key] = value
         return value
 
@@ -386,7 +391,12 @@ class Smart(Generic[T]):
             key=key,
             required=True,
         )
-        dictionary[last_key] = value = function(dictionary[last_key])
+
+        value = function(dictionary[last_key])
+        if isinstance(value, dict):
+            value = dictutil.normalize(value)
+
+        dictionary[last_key] = value
         return value
 
     def remove(
@@ -611,12 +621,14 @@ class Smart(Generic[T]):
         self,
         function: Optional[Callable[['Smart'], Any]] = None,
         path: Optional[Path] = None,
+        mode: Optional[str] = None,
     ) -> 'Smart[T]':
         """Runs main function.
 
         Args:
             function: Main function to be run.
             path: Path of params file.
+            mode: Mode of params file.
 
         Returns:
             Smart object.
@@ -624,6 +636,7 @@ class Smart(Generic[T]):
         """
         parser = create_argument_parser(
             default_path=path,
+            default_mode=mode,
         )
         args = parse_arguments(parser)
 
@@ -789,7 +802,10 @@ class Smart(Generic[T]):
         return self._init(
             callable_=callable_,
             trace=trace,
-            kwargs=kwargs,
+            kwargs=self._init_dict(
+                dictionary=kwargs,
+                trace=trace,
+            ),
         )
 
     def _init(
@@ -802,11 +818,6 @@ class Smart(Generic[T]):
         args = args or tuple()
         kwargs = kwargs or dict()
 
-        kwargs = self._init_dict(
-            dictionary=kwargs,
-            trace=trace,
-        )
-
         callable_trace = strutil.join_objects(trace, typeutil.get_name(callable_))
 
         if self.check_missings:
